@@ -5,6 +5,7 @@
 //           Konrad-Zuse-Zentrum Berlin (Germany)
 //           email: pfender@zib.de
 // date:     09/25/2000
+// license:  this file may be freely distributed under the terms of EPL
 // comments: please scan this file for '???' and read the comments
 //-----------------------------------------------------------------------------
 // Copyright (C) 2000, Tobias Pfender, International Business Machines
@@ -15,6 +16,10 @@
 #  pragma warning(disable:4786)
 #endif
 
+#ifdef NDEBUG
+#undef NDEBUG
+#endif
+
 #include "OsiConfig.h"
 
 #include <cassert>
@@ -28,13 +33,10 @@
 #include "OsiColCut.hpp"
 #include "CoinPackedMatrix.hpp"
 
-#ifdef NDEBUG
-#undef NDEBUG
-#endif
-
 // Added so build windows build with dsp files works,
 // when not building with cplex.
 #ifdef COIN_HAS_CPX
+#include "cplex.h"
 
 void OsiCpxSolverInterface::printBounds()
 {
@@ -79,7 +81,6 @@ void OsiCpxSolverInterfaceUnitTest( const std::string & mpsDir, const std::strin
 {
   // Test default constructor
   {
-    assert( OsiCpxSolverInterface::getNumInstances()==0 );
     OsiCpxSolverInterface m;
     assert( m.obj_==NULL );
     assert( m.collower_==NULL );
@@ -96,18 +97,15 @@ void OsiCpxSolverInterfaceUnitTest( const std::string & mpsDir, const std::strin
     assert( m.matrixByCol_==NULL );
     assert( m.coltype_==NULL );
     assert( m.coltypesize_==0 );
-    assert( OsiCpxSolverInterface::getNumInstances()==1 );
     assert( m.getApplicationData() == NULL );
     int i=2346;
     m.setApplicationData(&i);
     assert( *((int *)(m.getApplicationData())) == i );
   }
-  assert( OsiCpxSolverInterface::getNumInstances()==0 );
 
   {    
     CoinRelFltEq eq;
     OsiCpxSolverInterface m;
-    assert( OsiCpxSolverInterface::getNumInstances()==1 );
     std::string fn = mpsDir+"exmip1";
     m.readMps(fn.c_str(),"mps");
     int ad = 13579;
@@ -647,8 +645,8 @@ void OsiCpxSolverInterfaceUnitTest( const std::string & mpsDir, const std::strin
 
         // Change CPLEX Model by adding free row
         OsiRowCut rc;
-        rc.setLb(-DBL_MAX);
-        rc.setUb( DBL_MAX);
+        rc.setLb(-COIN_DBL_MAX);
+        rc.setUb( COIN_DBL_MAX);
         OsiCuts cuts;
         cuts.insert(rc);
         siC1.applyCuts(cuts);
@@ -780,11 +778,7 @@ void OsiCpxSolverInterfaceUnitTest( const std::string & mpsDir, const std::strin
       assert( lhsmbr->getNumElements() == 14 );
     }
     
-    //--------------
-    
-    assert(OsiCpxSolverInterface::getNumInstances()==1);
   }
-  assert(OsiCpxSolverInterface::getNumInstances()==0);
 
     
   // Do common solverInterface testing by calling the
